@@ -6,8 +6,8 @@
         <translation>Γεια σου κόσμε:</translation>
     </message>
     <message>
-        <source>Display Text Configuretion</source>
-        <translation>Εμφάνιση διαμόρφωσης κειμένου</translation>
+        <source>Display Text Configuration</source>
+        <translation>Εμφάνιση Ρυθμίσεων Κειμένου</translation>
     </message>
     <message>
         <source>Edit HTML</source>
@@ -18,7 +18,7 @@
     <name>QObject</name>
     <message>
         <source>Display simple text. A debugging/sample widget.</source>
-        <translation>Ένα γραφικό συστατικό για την εμφάνιση απλού κειμένου</translation>
+        <translation>Εμφάνιση απλού κειμένου. Ένα γραφικό συστατικό αποσφαλμάτωσης.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
