@@ -3,7 +3,7 @@
     <name>PanelScreenSaver</name>
     <message>
         <source>Panel Screensaver Global shorcut: &apos;%1&apos; cannot be registered</source>
-        <translation>Klávesovou zkratku pro modul &quot;Šetřič obrazovky&quot; &apos;%1&apos; nelze zapsat</translation>
+        <translation>Klávesovou zkratku pro modul Šetřič obrazovky &apos;%1&apos; nelze zapsat</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
